@@ -176,6 +176,14 @@ public:
 	virtual PageItem_TextFrame * asTextFrame() { return NULL; }
 	virtual PageItem_LatexFrame * asLatexFrame() { return NULL; }
 
+	virtual bool isImageFrame() const { return false; }
+	virtual bool isLine()       const { return false; }
+	virtual bool isPathText()   const { return false; }
+	virtual bool isPolygon()    const { return false; }
+	virtual bool isPolyLine()   const { return false; }
+	virtual bool isTextFrame()  const { return false; }
+	virtual bool isLatexFrame() const { return false; }
+
 
 	/** @brief Frame Type
 	 *
@@ -280,6 +288,7 @@ public:
 	void getBoundingRect(double *x1, double *y1, double *x2, double *y2) const;
 	void getVisualBoundingRect(double *x1, double *y1, double *x2, double *y2) const;
 	QRectF getBoundingRect() const;
+	QRectF getCurrentBoundingRect(double moreSpace = 0.0) const;
 	QRectF getVisualBoundingRect() const;
 	void getTransform(QMatrix& mat) const;
 	QMatrix getTransform() const;
@@ -404,6 +413,7 @@ public:
 	QString Pfile3;
 	QString externalFile() const { return Pfile; }
 	void setExternalFile(QString val);
+	void setImagePagenumber(int num) { pixm.imgInfo.actualPageNumber = num; }
 	
 	//FIXME: maybe these should go into annotation?
 	QString fileIconPressed() const { return Pfile2; }
@@ -517,7 +527,7 @@ public:
 	bool isSingleSel;
 	bool isGroupControl;
 	PageItem *groupsLastItem;
-	void setGroupsLastItem(PageItem* lnk) { groupsLastItem = lnk; }
+	void setGroupsLastItem(PageItem* item);
 	double BoundingX;
 	double BoundingY;
 	double BoundingW;
@@ -1045,6 +1055,7 @@ protected:
 	void restoreShapeType(SimpleState *state, bool isUndo);
 	void restoreLayer(SimpleState *state, bool isUndo);
 	void restoreGetImage(SimpleState *state, bool isUndo);
+	void restoreGroupsLastItem(SimpleState *state, bool isUndo);
 
 	void restoreShapeContour(UndoState *state, bool isUndo);
 	void restoreImageEffects(UndoState *state, bool isUndo);
