@@ -227,10 +227,18 @@ bool Scribus12Format::loadFile(const QString & fileName, const FileFormat & /* f
 	// Load the document text
 	QString f(readSLA(fileName));
 	if (f.isEmpty())
+	{
+		setFileReadError();
 		return false;
+	}
 	// Build the DOM from it
-	if (!docu.setContent(f))
+	QString errorMsg;
+	int errorLine, errorColumn;
+	if (!docu.setContent(f, &errorMsg, &errorLine, &errorColumn))
+	{
+		setDomParsingError(errorMsg, errorLine, errorColumn);
 		return false;
+	}
 	// Get file directory
 	QString fileDir = QFileInfo(fileName).absolutePath();
 	// and begin loading the doc
@@ -799,6 +807,8 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 		OB->Pcolor2 = obj->attribute("PCOLOR2");
 		OB->TxtFill = obj->attribute("TXTFILL", "Black");
 	}
+	if (OB->Pwidth == 0.0)
+		OB->Pcolor2 = CommonStrings::None;
 	OB->Shade = obj->attribute("SHADE").toInt();
 	OB->Shade2 = obj->attribute("SHADE2").toInt();
 	OB->FillRule = obj->attribute("fillRule", "1").toInt();
@@ -1173,9 +1183,17 @@ bool Scribus12Format::loadPage(const QString & fileName, int pageNumber, bool Mp
 	QDomDocument docu("scridoc");
 	QString f(readSLA(fileName));
 	if (f.isEmpty())
+	{
+		setFileReadError();
 		return false;
-	if(!docu.setContent(f))
+	}
+	QString errorMsg;
+	int errorLine, errorColumn;
+	if (!docu.setContent(f, &errorMsg, &errorLine, &errorColumn))
+	{
+		setDomParsingError(errorMsg, errorLine, errorColumn);
 		return false;
+	}
 	QString fileDir = QFileInfo(fileName).absolutePath();
 	ScColor lf = ScColor();
 	QDomElement elem=docu.documentElement();
@@ -1679,7 +1697,7 @@ QString Scribus12Format::AskForFont(SCFonts &avail, QString fStr, ScribusDoc *do
 */
 bool Scribus12Format::readStyles(const QString& fileName, ScribusDoc* doc, StyleSet<ParagraphStyle> &docParagraphStyles)
 {
-	ParagraphStyle vg;
+	ParagraphStyle pstyle;
 	QDomDocument docu("scridoc");
 	QString tmpf, tmf;
 // 	DoFonts.clear();
@@ -1700,7 +1718,10 @@ bool Scribus12Format::readStyles(const QString& fileName, ScribusDoc* doc, Style
 		{
 			QDomElement pg=PAGE.toElement();
 			if(pg.tagName()=="STYLE")
-				GetStyle(&pg, &vg, &docParagraphStyles, doc, false);
+			{
+				pstyle.erase();
+				GetStyle(&pg, &pstyle, &docParagraphStyles, doc, false);
+			}
 			PAGE=PAGE.nextSibling();
 		}
 		DOC=DOC.nextSibling();
