@@ -22,7 +22,7 @@ ScCLocale::ScCLocale()
 #if defined(Q_WS_WIN)
 	cLocale = _create_locale(LC_ALL, "C");
 #else
-  #if not defined(Q_OS_SOLARIS)
+  #if not defined(Q_OS_SOLARIS) and not defined(Q_OS_OPENBSD)
 	cLocale = newlocale(LC_ALL_MASK, "C", NULL);
   #endif
 #endif
@@ -33,7 +33,7 @@ ScCLocale::~ScCLocale()
 #if defined(Q_WS_WIN)
 	_free_locale(cLocale);
 #else
-  #if not defined(Q_OS_SOLARIS)
+  #if not defined(Q_OS_SOLARIS) and not defined(Q_OS_OPENBSD)
 	freelocale(cLocale);
   #endif
 #endif
@@ -87,9 +87,9 @@ float ScCLocale::toFloatC(const QString& str, float defValue)
 	return ret;
 }
 
-QString ScCLocale::toQStringC(double d)
+QString ScCLocale::toQStringC(double d, int prec)
 {
-	return that()->qLocale.toString(d, 'f', 3);
+	return that()->qLocale.toString(d, 'f', prec);
 }
 
 double ScCLocale::strtod ( const char * str, char ** endptr )
@@ -108,7 +108,7 @@ double ScCLocale::strtod ( const char * str, char ** endptr )
 #if defined(Q_WS_WIN)
 		return _strtod_l(str, endptr, that()->cLocale);
 #else
-  #if defined(Q_OS_SOLARIS)
+  #if defined(Q_OS_SOLARIS) or defined (Q_OS_OPENBSD)
 		char *oldlocale=setlocale(LC_NUMERIC, NULL);
 		double result(0.0);
 		setlocale(LC_NUMERIC, "C");
