@@ -21,14 +21,14 @@
 #include <xlocale.h>
 #endif
 
-#if defined(Q_OS_SOLARIS)
+#if defined(Q_OS_SOLARIS) || defined (Q_OS_OPENBSD)
 #include <locale.h>
 #endif
 
 #if defined(Q_WS_WIN)
 #define XLocaleType _locale_t
 #else
-  #if defined (Q_OS_SOLARIS)
+  #if defined (Q_OS_SOLARIS) || defined (Q_OS_OPENBSD)
   #define XLocaleType char*   //dummy?
   #else
   #define XLocaleType locale_t
@@ -52,7 +52,7 @@ class SCRIBUS_API ScCLocale
 		static double toDoubleC(const QString& str, double defValue);
 		static float toFloatC(const QString& str, bool * ok = 0);
 		static float toFloatC(const QString& str, float defValue);
-		static QString toQStringC(double d);
+		static QString toQStringC(double d, int prec = 3);
 		static double strtod ( const char * str, char ** endptr );
 		
 };
