@@ -953,6 +953,8 @@ void ScPainter::drawVPath( int mode )
 		else if (fillMode == 2)
 		{
 			cairo_pattern_t *pat;
+			bool   isFirst = true;
+			double rampPoint, lastPoint = 0.0;
 			double x1 = fill_gradient.origin().x();
 			double y1 = fill_gradient.origin().y();
 			double x2 = fill_gradient.vector().x();
@@ -966,6 +968,10 @@ void ScPainter::drawVPath( int mode )
 			for( int offset = 0 ; offset < colorStops.count() ; offset++ )
 			{
 				qStopColor = colorStops[ offset ]->color;
+				rampPoint  = colorStops[ offset ]->rampPoint;
+				if ((lastPoint == rampPoint) && (!isFirst))
+					continue;
+				isFirst = false;
 				int h, s, v, sneu, vneu;
 				int shad = colorStops[offset]->shade;
 				qStopColor.getHsv(&h, &s, &v);
@@ -975,7 +981,8 @@ void ScPainter::drawVPath( int mode )
 				double a = colorStops[offset]->opacity;
 				double r, g, b;
 				qStopColor.getRgbF(&r, &g, &b);
-				cairo_pattern_add_color_stop_rgba (pat, colorStops[ offset ]->rampPoint, r, g, b, a);
+				cairo_pattern_add_color_stop_rgba (pat, rampPoint, r, g, b, a);
+				lastPoint = rampPoint;
 			}
 			cairo_set_source (m_cr, pat);
 			cairo_clip_preserve (m_cr);
@@ -984,6 +991,7 @@ void ScPainter::drawVPath( int mode )
 		}
 		else if (fillMode == 3)
 		{
+			cairo_set_antialias(m_cr, CAIRO_ANTIALIAS_NONE);
 			cairo_surface_t *image2 = cairo_image_surface_create_for_data ((uchar*)m_pattern->getPattern()->bits(), CAIRO_FORMAT_ARGB32, m_pattern->getPattern()->width(), m_pattern->getPattern()->height(), m_pattern->getPattern()->width()*4);
 			cairo_pattern_t *m_pat = cairo_pattern_create_for_surface(image2);
 			cairo_pattern_set_extend(m_pat, CAIRO_EXTEND_REPEAT);
@@ -994,6 +1002,7 @@ void ScPainter::drawVPath( int mode )
 			qmatrix.translate(patternOffsetX, patternOffsetY);
 			qmatrix.rotate(patternRotation);
 			qmatrix.scale(patternScaleX, patternScaleY);
+			qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern()->width()), m_pattern->height / static_cast<double>(m_pattern->getPattern()->height()));
 			cairo_matrix_init(&matrix, qmatrix.m11(), qmatrix.m12(), qmatrix.m21(), qmatrix.m22(), qmatrix.dx(), qmatrix.dy());
 			cairo_matrix_invert(&matrix);
 			cairo_pattern_set_matrix (m_pat, &matrix);
@@ -1002,6 +1011,7 @@ void ScPainter::drawVPath( int mode )
 			cairo_paint_with_alpha (m_cr, fill_trans);
 			cairo_pattern_destroy (m_pat);
 			cairo_surface_destroy (image2);
+			cairo_set_antialias(m_cr, CAIRO_ANTIALIAS_DEFAULT);
 		}
 	}
 	else
@@ -1058,6 +1068,8 @@ void ScPainter::drawVPath(int mode)
 		else if (fillMode == 2)
 		{
 			QGradient pat;
+			bool   isFirst = true;
+			double rampPoint, lastPoint = 0.0;
 			double x1 = fill_gradient.origin().x();
 			double y1 = fill_gradient.origin().y();
 			double x2 = fill_gradient.vector().x();
@@ -1071,6 +1083,10 @@ void ScPainter::drawVPath(int mode)
 			for( int offset = 0 ; offset < colorStops.count() ; offset++ )
 			{
 				qStopColor = colorStops[ offset ]->color;
+				rampPoint  = colorStops[ offset ]->rampPoint;
+				if ((lastPoint == rampPoint) && (!isFirst))
+					continue;
+				isFirst = false;
 				int h, s, v, sneu, vneu;
 				int shad = colorStops[offset]->shade;
 				qStopColor.getHsv(&h, &s, &v);
@@ -1079,21 +1095,27 @@ void ScPainter::drawVPath(int mode)
 				qStopColor.setHsv(h, sneu, vneu);
 				qStopColor.setAlphaF(colorStops[offset]->opacity);
 				pat.setColorAt(colorStops[ offset ]->rampPoint, qStopColor);
+				lastPoint = rampPoint;
 			}
 			painter.setOpacity(fill_trans);
 			painter.fillPath(m_path, pat);
 		}
 		else if (fillMode == 3)
 		{
+			painter.setRenderHint(QPainter::Antialiasing, false);
+			painter.setRenderHint(QPainter::SmoothPixmapTransform, false);
 			QMatrix qmatrix;
 			qmatrix.translate(patternOffsetX, patternOffsetY);
 			qmatrix.rotate(patternRotation);
 			qmatrix.scale(patternScaleX, patternScaleY);
+			qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern()->width()), m_pattern->height / static_cast<double>(m_pattern->getPattern()->height()));
 			QBrush brush = QBrush(*m_pattern->getPattern());
 			brush.setMatrix(qmatrix);
 			painter.rotate(0.0001);	// hack to get Qt-4's strange pattern rendering working
 			painter.setOpacity(fill_trans);
 			painter.fillPath(m_path, brush);
+			painter.setRenderHint(QPainter::Antialiasing, true);
+			painter.setRenderHint(QPainter::SmoothPixmapTransform, true);
 		}
 	}
 	else
