@@ -12,6 +12,7 @@ for which a new license (GPL+exception) is in place.
 #error "This file compiles on win32 platform only!"
 #endif
 
+#include <algorithm>
 #include <memory>
 #include <valarray>
 #include <windows.h>
@@ -471,7 +472,7 @@ bool ScPrintEngine_GDI::printPage_PS ( ScribusDoc* doc, Page* page, PrintOptions
 		double bleedH = options.bleeds.Left + options.bleeds.Right;
 		double bleedV = options.bleeds.Top  + options.bleeds.Bottom;
 		StartPage( printerDC );
-		succeed = sendPSFile( tempFilePath, printerDC, page->width() + bleedH, page->height() + bleedV);
+		succeed = sendPSFile( tempFilePath, printerDC, page->width() + bleedH, page->height() + bleedV, (page->PageOri == 1));
 		EndPage( printerDC );
 	}
 	
@@ -497,7 +498,7 @@ bool ScPrintEngine_GDI::printPage_PS_Sep( ScribusDoc* doc, Page* page, PrintOpti
 	return succeed;
 }
 
-bool ScPrintEngine_GDI::sendPSFile( QString filePath, HDC printerDC, int pageWidth, int pageHeight  )
+bool ScPrintEngine_GDI::sendPSFile( QString filePath, HDC printerDC, int pageWidth, int pageHeight, bool landscape )
 {
 	int  escape;
 	int  logPixelsX;
@@ -553,9 +554,30 @@ bool ScPrintEngine_GDI::sendPSFile( QString filePath, HDC printerDC, int pageWid
 	if( ExtEscape( printerDC, escape, sizeof(sps), (LPCSTR) &sps, 0, NULL) <= 0 )
 		return false;
 
+	// Match Postscript and GDI coordinate system
+	sprintf( (char*) sps.data, "0 %0.3f neg translate\n", (double) physicalHeight );
+	sps.numBytes = strlen( (char*) sps.data );
+	if( ExtEscape( printerDC, escape, sizeof(sps), (LPCSTR) &sps, 0, NULL) <= 0 )
+		return false;
+
+	// In case of landscape printing, pslib will rotate the page
+	// we must take that into account
+	if (landscape)
+	{
+		sprintf( (char*) sps.data, "-90 rotate %0.3f %0.3f translate\n", (double) -pageHeight, 0.0);
+		sps.numBytes = strlen( (char*) sps.data );
+		if( ExtEscape( printerDC, escape, sizeof(sps), (LPCSTR) &sps, 0, NULL) <= 0 )
+			return false;
+		transx = ( physicalHeight - pageHeight ) / -2.0;
+		transy = ( physicalWidth  - pageWidth ) / 2.0;
+	}
+	else
+	{
+		transx = ( physicalWidth  - pageWidth ) / 2.0;
+		transy = ( physicalHeight - pageHeight ) / 2.0;
+	}
+
 	// Center the printed page in paper zone
-	transx = ( physicalWidth - pageWidth ) / 2.0;
-	transy = ( pageHeight - physicalHeight ) / 2.0 - pageHeight;
 	sprintf( (char*) sps.data, "%0.3f %0.3f translate\n", transx, transy );
 	sps.numBytes = strlen( (char*) sps.data );
 	if( ExtEscape( printerDC, escape, sizeof(sps), (LPCSTR) &sps, 0, NULL) <= 0 )
