@@ -630,15 +630,26 @@ void StoryText::applyCharStyle(int pos, uint len, const CharStyle& style )
 	if (len == 0)
 		return;
 
+	int lastParStart = pos == 0? 0 : -1;
 	ScText* itText;
 	for (uint i=pos; i < pos+len; ++i) {
 		itText = d->at(i);
-		// #6165 : applying style on last character applies style on whole text on next open 
-		/*if (itText->ch == SpecialChars::PARSEP && itText->parstyle != NULL)
-			itText->parstyle->charStyle().applyCharStyle(style);*/
+		// #6165 : applying style on last character applies style on whole text on next open
+		// #9173 et. al.: move charstyle to parstyle if whole paragraph is affected
+		if (itText->ch == SpecialChars::PARSEP && itText->parstyle != NULL && lastParStart >= 0)
+		{
+			eraseCharStyle(lastParStart, i - lastParStart, style);
+			itText->parstyle->charStyle().applyCharStyle(style);
+			lastParStart = i + 1;
+		}
 		itText->applyCharStyle(style);
 	}
-
+	if (pos + signed(len) == length() && lastParStart >= 0)
+	{
+		eraseCharStyle(lastParStart, length() - lastParStart, style);
+		d->trailingStyle.charStyle().applyCharStyle(style);
+	}
+	
 	invalidate(pos, pos + len);
 }
 
@@ -663,6 +674,10 @@ void StoryText::eraseCharStyle(int pos, uint len, const CharStyle& style )
 			itText->parstyle->charStyle().eraseCharStyle(style);
 		itText->eraseCharStyle(style);
 	}
+	if (pos + signed(len) == length())
+	{
+		d->trailingStyle.charStyle().eraseCharStyle(style);
+	}
 	
 	invalidate(pos, pos + len);
 }
@@ -1613,6 +1628,19 @@ public:
 	{
 		StoryText* story = this->dig->top<StoryText>(1);
 		PageItem* obj = this->dig->top<PageItem>(0);
+		// FIXME : currently inline objects are added to doc items when parsing
+		// We have to remove them from object list and add them to the FrameItems list
+		// before inserting them in story object
+		QList<PageItem*> *items = obj->doc()->Items;
+		if (items->count() > 0)
+		{
+			if (items->last() == obj) // try a fast path first
+				items->removeLast();
+			else
+				items->removeAll(obj);
+		}
+		obj->doc()->FrameItems.append(obj);
+		obj->ItemNr = obj->doc()->FrameItems.count() - 1;
 		story->insertObject(-1, obj);
 	}
 };
